camelot.camelot

Package camelot :: Package camelot |
[hide private]
[frames] | no frames]

# Package camelot

source code

Submodules | [hide private]
camelot.camelot.bin camelot.camelot.empty_project camelot.camelot.empty_project.application_admin camelot.camelot.empty_project.main camelot.camelot.empty_project.model camelot.camelot.empty_project.settings camelot.camelot.model camelot.camelot.model.authentication: Set of classes to store persons, organizations, relationships and permissions camelot.camelot.model.i18n: Set of classes to enable internationalization of the user interface camelot.camelot.model.memento: Set of classes to keep track of changes to objects and be able to restore their state camelot.camelot.model.synchronization: Functionallity to synchronize elements from the camelot database against other databases camelot.camelot.types camelot.camelot.view camelot.camelot.view.application_admin: Admin class, specify how the main window should look like camelot.camelot.view.art: Manage icons and artworks camelot.camelot.view.controls camelot.camelot.view.controls.actions: Action buttons camelot.camelot.view.controls.animation camelot.camelot.view.controls.appscheme: encapsulates various ms office schemes camelot.camelot.view.controls.delegates: Contains classes for using custom delegates camelot.camelot.view.controls.editors: Editors for various type of values camelot.camelot.view.controls.filter: Controls to filter data camelot.camelot.view.controls.formview: form view camelot.camelot.view.controls.inheritance: Controls related to visualizing object hierarchy camelot.camelot.view.controls.modeltree: custom tree and tree-items widgets camelot.camelot.view.controls.navpane: left navigation pane camelot.camelot.view.controls.printer: class to handle printing camelot.camelot.view.controls.schemer: module that encapsulate various ms office schemes camelot.camelot.view.controls.search camelot.camelot.view.controls.tableview: Tableview camelot.camelot.view.elixir_admin camelot.camelot.view.export camelot.camelot.view.export.desktop_service camelot.camelot.view.export.excel camelot.camelot.view.export.outlook camelot.camelot.view.export.printer camelot.camelot.view.export.word camelot.camelot.view.field_attributes: Default field attributes for various sqlalchemy column types camelot.camelot.view.fifo camelot.camelot.view.filters: Python structures to represent filters. camelot.camelot.view.forms: Python structures to represent interface forms. camelot.camelot.view.helpers: collection of helper functions camelot.camelot.view.mainwindow: Main window GUI camelot.camelot.view.model_thread camelot.camelot.view.plugins: Plugins to include custom Camelot editors into QT Designer camelot.camelot.view.plugins.codeeditorplugin camelot.camelot.view.plugins.dateeditorplugin camelot.camelot.view.plugins.imageeditorplugin camelot.camelot.view.plugins.manytooneeditorplugin camelot.camelot.view.plugins.onetomanyeditorplugin camelot.camelot.view.plugins.richtexteditorplugin camelot.camelot.view.proxy: Proxy objects for the model that live in the GUI thread and are able to respond immediately. camelot.camelot.view.proxy.collection_proxy: Proxy representing a collection of entities that live in the model thread. camelot.camelot.view.proxy.queryproxy: Proxies representing the results of a query camelot.camelot.view.remote_signals camelot.camelot.view.response_handler: QT Response handler class to be used when constructing a model thread. camelot.camelot.view.search: Helper functions to search through a collection of entities camelot.camelot.view.validator camelot.camelot.view.workspace: This module provides a singleton workspace that can be used by views and widget to create new windows or raise existing ones